var languageNames = {
"en-US": "Angla (Usono)",
"sq": "Albana",
"am": "Amhara",
"ar": "Araba",
"ast": "Astura",
"bn": "Bengala",
"bn-IN": "Bengala (Barato)",
"bs": "Bosna",
"bg": "Bulgara",
"ca": "Kataluna",
"ca-valencia": "Catalan (Valencia)",
"zh-CN": "Ĉina (simpligita)",
"zh-TW": "Ĉina (tradicia)",
"hr": "Kroata",
"cs": "Ĉeĥa",
"da": "Dana",
"nl": "Nederlanda",
"dz": "Butana",
"en-GB": "Angla (UR)",
"en-ZA": "Angla (SA)",
"eo": "Esperanto",
"et": "Estona",
"eu": "Eŭska",
"fi": "Finna",
"fr": "Franca",
"gl": "Galega",
"ka": "Kartvela",
"de": "Germana",
"el": "Greka",
"gu": "Guĝarata",
"he": "Hebrea",
"hi": "Hindia",
"hu": "Hungara",
"id": "Indonezia",
"is": "Islanda",
"it": "Itala",
"ja": "Japana",
"km": "Kamboĝa",
"ko": "Korea",
"lo": "Laosa",
"lv": "Latva",
"lt": "Litova",
"mk": "Makedona",
"ne": "Nepalia",
"nn": "Norvega (nynorsk)",
"nb": "Norvega (bokmål)",
"om": "Oroma",
"pl": "Pola",
"pt": "Portugala",
"pt-BR": "Portuguese (Brazil)",
"ro": "Rumana",
"ru": "Rusa",
"sid": "Sidama",
"si": "Sinhala",
"sk": "Slovaka",
"sl": "Slovena",
"dsb": "Sorbian (Lower)",
"hsb": "Sorbian (Upper)",
"es": "Hispana",
"sv": "Sveda",
"tg": "Taĝika",
"ta": "Tamila",
"bo": "Tibeta",
"tr": "Turka",
"ug": "Ujgura",
"uk": "Ukraina",
"vi": "Vjetnama",
};
